"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var seng_disposable_1 = require("seng-disposable");
/**
 * Data object that is created on every call to [[EventDispatcher.addEventListener]]. The object is
 * saved on the [[EventDispatcher.listeners]] object for internal use but is also returned by the
 * _addEventListener_ method as a way to remove the listener.
 */
var EventListenerData = (function (_super) {
    tslib_1.__extends(EventListenerData, _super);
    /**
     * @param dispatcher The EventDispatcher on which this listener listens for events
     * @param type The type of event this listener responds to
     * @param handler The handler function that will be called when a matching event is dispatched
     * @param useCapture Set to the _useCapture_ argument passed to [[EventDispatcher.addEventListener|addEventListener]]
     * @param priority Set to the _priority_ argument passed to [[EventDispatcher.addEventListener|addEventListener]].
     * Used to sort the listener within the [[EventDispatcher._listeners|_listeners]] object of the EventDispatcher
     */
    function EventListenerData(dispatcher, type, handler, useCapture, priority) {
        var _this = _super.call(this) || this;
        _this.dispatcher = dispatcher;
        _this.type = type;
        _this.handler = handler;
        _this.useCapture = useCapture;
        _this.priority = priority;
        /**
         * This property will be set to _true_ by the [[EventDispatcher]] this listener is bound to when
         * the listener is removed. This is to make sure the handler is not called, even if the listener
         * is removed while dispatching the event.
         */
        _this.isRemoved = false;
        return _this;
    }
    /**
     * Detaches this event listener from its EventDispatcher. The handler function on this listener will
     * no longer be called in response to dispatched events.
     */
    EventListenerData.prototype.dispose = function () {
        if (this.dispatcher) {
            this.dispatcher.removeEventListener(this.type, this.handler, this.useCapture);
            this.dispatcher = null;
        }
        _super.prototype.dispose.call(this);
    };
    return EventListenerData;
}(seng_disposable_1.default));
exports.default = EventListenerData;
